summaryrefslogtreecommitdiffstats
path: root/compiler/image_writer.h
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/image_writer.h')
-rw-r--r--compiler/image_writer.h14
1 files changed, 3 insertions, 11 deletions
diff --git a/compiler/image_writer.h b/compiler/image_writer.h
index 622eb1985b..ad690389e9 100644
--- a/compiler/image_writer.h
+++ b/compiler/image_writer.h
@@ -49,7 +49,7 @@ class ImageSpace;
class ClassTable;
-static constexpr int kInvalidFd = -1;
+static constexpr int kInvalidImageFd = -1;
// Write a Space built during compilation for use during execution.
class ImageWriter FINAL {
@@ -103,15 +103,11 @@ class ImageWriter FINAL {
uint8_t* GetOatFileBegin(const char* oat_filename) const;
// If image_fd is not kInvalidFd, then we use that for the image file. Otherwise we open
// the names in image_filenames.
- // If oat_fd is not kInvalidFd, then we use that for the oat file. Otherwise we open
- // the names in oat_filenames.
bool Write(int image_fd,
const std::vector<const char*>& image_filenames,
- int oat_fd,
- const std::vector<const char*>& oat_filenames,
- const std::string& oat_location)
+ const std::vector<const char*>& oat_filenames)
REQUIRES(!Locks::mutator_lock_);
uintptr_t GetOatDataBegin(const char* oat_filename) {
@@ -451,10 +447,6 @@ class ImageWriter FINAL {
const ImageInfo& GetConstImageInfo(const char* oat_filename) const;
const ImageInfo& GetImageInfo(size_t index) const;
- // Find an already strong interned string in the other images or in the boot image. Used to
- // remove duplicates in the multi image and app image case.
- mirror::String* FindInternedString(mirror::String* string) SHARED_REQUIRES(Locks::mutator_lock_);
-
const CompilerDriver& compiler_driver_;
// Beginning target image address for the first image.
@@ -103,15 +103,11 @@ class ImageWriter FINAL {
uint8_t* GetOatFileBegin(const char* oat_filename) const;
- // If image_fd is not kInvalidFd, then we use that for the image file. Otherwise we open
+ // If image_fd is not kInvalidImageFd, then we use that for the file. Otherwise we open
// the names in image_filenames.